# ontologia/codicem/anatomiam

> TODO: change the #item hashtags to "#vocab (Emerson Rocha, 2021-04-28 01:51 UTC)

> TODO: place all Terminologia Anatomica codes right after Q Codes (Emerson Rocha, 2021-04-28 01:51 UTC)

## terminologia-anatomica.hxl.csv
- [terminologia-anatomica-EXEMPLUM.hxl.csv](terminologia-anatomica-EXEMPLUM.hxl.csv)
- `urn:data:xz:eticaai:ontologia:codicem:anatomiam:terminologia-anatomica`
- https://github.com/HXL-CPLP/forum/issues/44

### Build script
- [make.sh](make.sh)

## See also:
- **"HXL-CPLP/forum/issues#44: Discussão geral de HXL na área de Medicina Legal (EN: Medical jurisprudence)"**
  - https://github.com/HXL-CPLP/forum/issues/44
- **"HXL-CPLP/forum/issues#41: HXL-CPLP-Vocab_BRA-policia-judiciaria"**
  - https://github.com/HXL-CPLP/forum/issues/44
